@@ -1,14 +1,19 @@
 #!/usr/bin/env python
 # PYTHON_ARGCOMPLETE_OK
-from . import main, calib, audio, async
-from .config import bitrates
-from . import version
-
+import argparse
+import logging
 import os
 import sys
 import zlib
-import logging
-import argparse
+
+import pkg_resources
+
+from . import async
+from . import audio
+from . import calib
+from . import main
+from .config import bitrates
+
 
 # Python 3 has `buffer` attribute for byte-based I/O
 _stdin = getattr(sys.stdin, 'buffer', sys.stdin)
@@ -97,6 +102,7 @@ def get_volume_cmd(args):
         for c in volume_controllers:
             if os.system(c['test']) == 0:
                 return c[args.command]
+    return None
 
 
 def wrap(cls, stream, enable):
@@ -188,11 +194,15 @@ class _Dummy(object):
         pass
 
 
+def _version():
+    return pkg_resources.require('amodem')[0].version
+
+
 def _main():
     fmt = ('Audio OFDM MODEM v{0:s}: '
            '{1:.1f} kb/s ({2:d}-QAM x {3:d} carriers) '
            'Fs={4:.1f} kHz')
-    description = fmt.format(version.__doc__,
+    description = fmt.format(_version(),
                              config.modem_bps / 1e3, len(config.symbols),
                              config.Nfreq, config.Fs / 1e3)
     interface = None
