@@ -1,13 +1,16 @@
+"""Calibration capabilities for amodem."""
+
+import itertools
+import logging
+import subprocess
+
+import numpy as np
+
 from . import common
 from . import dsp
 from . import sampling
 from . import stream
 
-import numpy as np
-import itertools
-import logging
-import subprocess
-
 log = logging.getLogger(__name__)
 
 
@@ -72,10 +75,10 @@ def detector(config, src, frame_length=200):
         else:
             msg = 'too {0} signal'.format(errors[flags.index(False)])
 
-        yield common.AttributeHolder(dict(
+        yield dict(
             freq=freq, rms=rms, peak=peak, coherency=coherency,
             total=total, success=success, msg=msg
-        ))
+        )
 
 
 def volume_calibration(result_iterator, volume_ctl):
@@ -90,7 +93,7 @@ def volume_calibration(result_iterator, volume_ctl):
     for index, result in enumerate(itertools.chain([None], result_iterator)):
         if index % iters_per_update == 0:
             if index > 0:  # skip dummy (first result)
-                sign = 1 if (result.total < target_level) else -1
+                sign = 1 if (result['total'] < target_level) else -1
                 level = level + step * sign
                 level = min(max(level, min_level), max_level)
                 step = step * 0.5
@@ -102,6 +105,7 @@ def volume_calibration(result_iterator, volume_ctl):
 
 
 def iter_window(iterable, size):
+    # pylint: disable=stop-iteration-return
     block = []
     while True:
         item = next(iterable)
@@ -111,12 +115,7 @@ def iter_window(iterable, size):
             yield block
 
 
-def recv(config, src, verbose=False, volume_cmd=None, dump_audio=None):
-    fmt = '{0.freq:6.0f} Hz: {0.msg:20s}'
-    if verbose:
-        fields = ['total', 'rms', 'coherency', 'peak']
-        fmt += ', '.join('{0}={{0.{0}:.4f}}'.format(f) for f in fields)
-
+def recv_iter(config, src, volume_cmd=None, dump_audio=None):
     volume_ctl = volume_controller(volume_cmd)
 
     if dump_audio:
@@ -125,6 +124,19 @@ def recv(config, src, verbose=False, volume_cmd=None, dump_audio=None):
     result_iterator = volume_calibration(result_iterator, volume_ctl)
     for _prev, curr, _next in iter_window(result_iterator, size=3):
         # don't log errors during frequency changes
-        if _prev.success and _next.success and _prev.freq != _next.freq:
-            curr.msg = curr.msg if curr.success else 'frequency change'
-        log.info(fmt.format(curr))
+        if _prev['success'] and _next['success']:
+            if _prev['freq'] != _next['freq']:
+                if not curr['success']:
+                    curr['msg'] = 'frequency change'
+        yield curr
+
+
+def recv(config, src, verbose=False, volume_cmd=None, dump_audio=None):
+    fmt = '{freq:6.0f} Hz: {msg:20s}'
+    log.info('verbose: %s', verbose)
+    if verbose:
+        fields = ['total', 'rms', 'coherency', 'peak']
+        fmt += ', '.join('{0}={{{0}:.4f}}'.format(f) for f in fields)
+
+    for state in recv_iter(config, src, volume_cmd, dump_audio):
+        log.info(fmt.format(**state))
