@@ -1,28 +1,38 @@
+""" Common package functionality.
+Commom utilities and procedures for amodem.
+
+"""
+
 import itertools
+import logging
+
 import numpy as np
 
-import logging
 log = logging.getLogger(__name__)
 
 scaling = 32000.0  # out of 2**15
 
 
 def load(fileobj):
+    """ Load signal from file object. """
     return loads(fileobj.read())
 
 
 def loads(data):
+    """ Load signal from memory buffer. """
     x = np.frombuffer(data, dtype='int16')
     x = x / scaling
     return x
 
 
 def dumps(sym):
+    """ Dump signal to memory buffer. """
     sym = sym.real * scaling
     return sym.astype('int16').tostring()
 
 
 def iterate(data, size, func=None, truncate=True, index=False):
+    """ Iterate over a signal, taking each time *size* elements. """
     offset = 0
     data = iter(data)
 
@@ -40,6 +50,9 @@ def iterate(data, size, func=None, truncate=True, index=False):
 
 
 def split(iterable, n):
+    """ Split an iterable of n-tuples into n iterables of scalars.
+    The k-th iterable will be equivalent to (i[k] for i in iter).
+    """
     def _gen(it, index):
         for item in it:
             yield item[index]
@@ -49,37 +62,30 @@ def split(iterable, n):
 
 
 def icapture(iterable, result):
+    """ Appends each yielded item to result. """
     for i in iter(iterable):
         result.append(i)
         yield i
 
 
 def take(iterable, n):
+    """ Take n elements from iterable, and return them as a numpy array. """
     return np.array(list(itertools.islice(iterable, n)))
 
 
-# "Python 3" zip re-implementation for Python 2
 def izip(iterables):
+    """ "Python 3" zip re-implementation for Python 2. """
+    # pylint: disable=stop-iteration-return
     iterables = [iter(iterable) for iterable in iterables]
     while True:
         yield tuple([next(iterable) for iterable in iterables])
 
 
 class Dummy(object):
+    """ Dummy placeholder object for testing and mocking. """
 
     def __getattr__(self, name):
         return self
 
     def __call__(self, *args, **kwargs):
         return self
-
-
-class AttributeHolder(object):
-
-    def __init__(self, d):
-        self.__dict__.update(d)
-
-    def __repr__(self):
-        items = sorted(self.__dict__.items())
-        args = ', '.join('{0}={1}'.format(k, v) for k, v in items)
-        return '{0}({1})'.format(self.__class__.__name__, args)
