@@ -1,10 +1,11 @@
-from . import common
-
+import binascii
 import functools
 import itertools
-import binascii
-import struct
 import logging
+import struct
+
+from . import common
+
 log = logging.getLogger(__name__)
 
 
@@ -26,8 +27,10 @@ class Checksum(object):
         payload = data[self.size:]
         expected = _checksum_func(payload)
         if received != expected:
-            log.warning('Invalid checksum: %04x != %04x', received, expected)
+            log.warning('Invalid checksum: %08x != %08x', received, expected)
             raise ValueError('Invalid checksum')
+        else:
+            log.debug('Good checksum: %08x', received)
         return payload
 
 
