@@ -1,14 +1,15 @@
+import functools
+import itertools
+import logging
+import time
+
+import numpy as np
+
 from . import dsp
 from . import common
 from . import framing
 from . import equalizer
 
-import numpy as np
-import logging
-import itertools
-import functools
-import time
-
 log = logging.getLogger(__name__)
 
 
@@ -28,6 +29,7 @@ class Receiver(object):
         self.equalizer = equalizer.Equalizer(config)
         self.carrier_index = config.carrier_index
         self.output_size = 0  # number of bytes written to output stream
+        self.freq_err_gain = 0.01 * self.Tsym  # integration feedback gain
 
     def _prefix(self, symbols, gain=1.0):
         S = common.take(symbols, len(equalizer.prefix))
@@ -48,10 +50,10 @@ class Receiver(object):
         log.debug('Prefix OK')
 
     def _train(self, sampler, order, lookahead):
-        Nfreq = len(self.frequencies)
         equalizer_length = equalizer.equalizer_length
         train_symbols = self.equalizer.train_symbols(equalizer_length)
-        train_signal = self.equalizer.modulator(train_symbols) * Nfreq
+        train_signal = (self.equalizer.modulator(train_symbols) *
+                        len(self.frequencies))
 
         prefix = postfix = equalizer.silence_length * self.Nsym
         signal_length = equalizer_length * self.Nsym + prefix + postfix
@@ -137,10 +139,10 @@ class Receiver(object):
 
     def _update_sampler(self, errors, sampler):
         err = np.array([e for v in errors.values() for e in v])
-        err = np.mean(np.angle(err))/(2*np.pi) if len(err) else 0
+        err = np.mean(np.angle(err))/(2*np.pi) if err.size else 0
         errors.clear()
 
-        sampler.freq -= 0.01 * err * self.Tsym
+        sampler.freq -= self.freq_err_gain * err
         sampler.offset -= err
 
     def _report_progress(self, noise, sampler):
