@@ -5,7 +5,7 @@ class Reader(object):
 
     wait = 0.2
     timeout = 2.0
-    bufsize = 4096
+    bufsize = (8 << 10)
 
     def __init__(self, fd, data_type=None, eof=False):
         self.fd = fd
@@ -43,3 +43,14 @@ class Reader(object):
         raise IOError('timeout')
 
     __next__ = next
+
+
+class Dumper(object):
+    def __init__(self, src, dst):
+        self.src = src
+        self.dst = dst
+
+    def read(self, size):
+        data = self.src.read(size)
+        self.dst.write(data)
+        return data
